@@ -1,7 +1,7 @@
 from pyvis.network import Network
 import networkx as nx
 
-def generate_network(rows: dict[str, list[str]], simplify=True):
+def generate_network(rows, simplify=True):
     graph = nx.Graph()
 
     for name in rows:
@@ -16,6 +16,10 @@ def generate_network(rows: dict[str, list[str]], simplify=True):
         graph.remove_nodes_from(list(nx.isolates(graph)))
         graph.remove_edges_from(list(nx.selfloop_edges(graph)))
 
+    # Write networkx graph to GML file
+    print("writing GML file")
+    nx.readwrite.write_gml(graph, "output.gml")
+
     net = Network(width="100%", height="100%")
     net.from_nx(graph)
     
